summaryrefslogtreecommitdiffstats
path: root/dive.c
diff options
context:
space:
mode:
authorGravatar Dirk Hohndel <dirk@hohndel.org>2015-02-10 15:19:01 -0800
committerGravatar Dirk Hohndel <dirk@hohndel.org>2015-02-10 15:19:57 -0800
commit6374d9cc0334c7dc7af908b4cb9233a091a48740 (patch)
treeb4ed6bc68568540e63397416285f1ca151998d23 /dive.c
parent8fa205a59dc221ad6739de62cdcafc3b655863f9 (diff)
downloadsubsurface-6374d9cc0334c7dc7af908b4cb9233a091a48740.tar.gz
These pO2 samples exist in both the Predator and the Petrel
Signed-off-by: Dirk Hohndel <dirk@hohndel.org>
Diffstat (limited to 'dive.c')
-rw-r--r--dive.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/dive.c b/dive.c
index dfb3dc783..fe7807c5e 100644
--- a/dive.c
+++ b/dive.c
@@ -883,11 +883,13 @@ void update_setpoint_events(struct divecomputer *dc)
if (dc->divemode == CCR)
new_setpoint = prefs.defaultsetpoint;
- if (dc->divemode == OC && same_string(dc->model, "Shearwater Predator")) {
+ if (dc->divemode == OC &&
+ (same_string(dc->model, "Shearwater Predator") ||
+ same_string(dc->model, "Shearwater Petrel"))) {
// make sure there's no setpoint in the samples
// this is an irreversible change - so switching a dive to OC
// by mistake when it's actually CCR is _bad_
// So we make sure, this comes from a Predator and we only remove
// pO2 values we would have computed anyway.
struct event *ev = get_next_event(dc->events, "gaschange");
struct gasmix *gasmix = get_gasmix_from_event(ev);
@@ -883,11 +883,13 @@ void update_setpoint_events(struct divecomputer *dc)
// this is an irreversible change - so switching a dive to OC
// by mistake when it's actually CCR is _bad_
- // So we make sure, this comes from a Predator and we only remove
+ // So we make sure, this comes from a Predator or Petrel and we only remove
// pO2 values we would have computed anyway.
struct event *ev = get_next_event(dc->events, "gaschange");